@@ -1,6 +1,4 @@
 """SAC policy class using PyTorch."""
-import collections
-
 import torch
 import torch.nn as nn
 from ray.rllib.utils import override
@@ -56,16 +54,18 @@ class SACTorchPolicy(TargetNetworksMixin, TorchPolicy):
         return super().make_module(obs_space, action_space, config)
 
     @override(TorchPolicy)
-    def make_optimizer(self):
+    def make_optimizers(self):
         config = self.config["torch_optimizer"]
         components = "actor critics alpha".split()
 
-        optims = {k: build_optimizer(self.module[k], config[k]) for k in components}
-        return collections.namedtuple("OptimizerCollection", components)(**optims)
+        return {
+            name: build_optimizer(self.module[name], config[name])
+            for name in components
+        }
 
     @override(TorchPolicy)
     def learn_on_batch(self, samples):
-        batch_tensors = self._lazy_tensor_dict(samples)
+        batch_tensors = self.lazy_tensor_dict(samples)
         info = {}
 
         info.update(self._update_critic(batch_tensors))
@@ -74,10 +74,10 @@ class SACTorchPolicy(TargetNetworksMixin, TorchPolicy):
             info.update(self._update_alpha(batch_tensors))
 
         self.update_targets("critics", "target_critics")
-        return self._learner_stats(info)
+        return info
 
     def _update_critic(self, batch_tensors):
-        with self.optimizer.critics.optimize():
+        with self.optimizers.optimize("critics"):
             critic_loss, info = self.loss_critic(batch_tensors)
             critic_loss.backward()
 
@@ -85,7 +85,7 @@ class SACTorchPolicy(TargetNetworksMixin, TorchPolicy):
         return info
 
     def _update_actor(self, batch_tensors):
-        with self.optimizer.actor.optimize():
+        with self.optimizers.optimize("actor"):
             actor_loss, info = self.loss_actor(batch_tensors)
             actor_loss.backward()
 
@@ -93,7 +93,7 @@ class SACTorchPolicy(TargetNetworksMixin, TorchPolicy):
         return info
 
     def _update_alpha(self, batch_tensors):
-        with self.optimizer.alpha.optimize():
+        with self.optimizers.optimize("alpha"):
             alpha_loss, info = self.loss_alpha(batch_tensors)
             alpha_loss.backward()
 
