@@ -3,6 +3,4 @@
 http://papers.nips.cc/paper/5796-learning-continuous-control-policies-by-stochastic-value-gradients
 """
 
-from .soft_svg import SoftSVGTrainer
-from .svg_inf import SVGInfTrainer
-from .svg_one import SVGOneTrainer
+from .policy import SVGTorchPolicy
