@@ -5,8 +5,8 @@ import pytest
 import torch
 from ray.rllib.utils.tracking_dict import UsageTrackingDict
 
+from raylab.pytorch.utils import convert_to_tensor
 from raylab.utils.debug import fake_batch
-from raylab.utils.pytorch import convert_to_tensor
 
 
 @pytest.fixture(
